<?php

if ( !class_exists( 'Plvc_Multiple_Plugin_Info' ) ) :

class Plvc_Multiple_Plugin_Info
{

	private $now;

	private $AddonRecord = '';
	private $AddonCheckCronHook = '';

	function init() {
		
		global $Plvc_Multiple;
		global $Plvc;
		
		$this->now = strtotime( 'now' );

		$this->AddonRecord = $Plvc_Multiple->ltd . '_setting';
		$this->AddonCheckCronHook = $Plvc_Multiple->ltd . '_update_check2';

		if( $Plvc->Current['admin'] && $Plvc->ClassManager->is_manager && !$Plvc->Current['ajax'] ) {
			
			add_action( 'admin_init' , array( $this , 'update_check_schedule' ) , 20 );
			add_action( 'network_admin_notices' , array( $this , 'update_notices' ) );
			add_action( 'admin_notices' , array( $this , 'update_notices' ) );
		
		}
		
		add_action( $this->AddonCheckCronHook , array( $this , 'cron_multiple_update_check' ) );

	}

	function update_check_schedule() {
		
		if( is_main_site( get_current_blog_id() ) ) {

			if ( !wp_next_scheduled( $this->AddonCheckCronHook ) ) {

				$setting_date = mktime( date( 'H' , $this->now ) , 0 , 0 , date( 'm' , $this->now ) , ( date( 'd' , $this->now ) + 1 ) , date( 'Y' , $this->now ) );
				wp_schedule_single_event( $setting_date , $this->AddonCheckCronHook );
				
			}

		}

	}

	function update_notices() {

		global $current_screen;
		global $Plvc_Multiple;
		global $Plvc;
		
		$latest = $this->get_current_latest_ver();
		
		if( empty( $latest ) )
			return false;

		if( version_compare( $Plvc_Multiple->ver , $latest , '<' )  ) {
			
			if( $current_screen->parent_base == $Plvc->Plugin['page_slug'] or $current_screen->id == 'plugins' or $current_screen->base == 'dashboard' ) {
				
				echo '<div class="updated">';

				$text = sprintf( __( 'There is a new version of %1$s available. <a href="%2$s" target="_blank">Latest version is here</a>' , $Plvc_Multiple->ltd ) , $Plvc_Multiple->name , $Plvc_Multiple->Plugin['links']['about'] );
				printf( '<p>%s</p>' , $text );

				echo '</div>';

			}
			
		}

	}

	function cron_multiple_update_check() {
		
		global $Plvc_Multiple;
		global $Plvc;

		$current_latest = $this->get_current_latest_ver();
		
		if( empty( $current_latest ) ) {

			$this->update_addon_data();
			
		} else {
			
			$file_url = $Plvc->Plugin['links']['author'] . 'wp-content/pl/' . $Plvc_Multiple->plugin_slug . '.txt';
			$raw_response = wp_remote_get( $file_url , array( 'timeout' => 120, 'httpversion' => '1.1' ) );

			if ( is_wp_error( $raw_response ) || 200 != wp_remote_retrieve_response_code( $raw_response ) )
				return false;
				
			$latest = maybe_unserialize( wp_remote_retrieve_body( $raw_response ) );

			if ( version_compare( $current_latest , $latest , '<' ) ) {
				
				$this->update_addon_data( $latest );
				
			}

		}

	}

	private function get_addon_data() {
		
		global $Plvc;

		$Data = array();

		if( $Plvc->Current['multisite'] ) {

			$GetData = get_option( $this->AddonRecord );

		} else {

			$GetData = get_option( $this->AddonRecord );

		}
		
		if( !empty( $GetData ) )
			$Data = $GetData;
			
		return $Data;

	}

	private function get_current_latest_ver() {
		
		$latest_ver = false;

		$Data = $this->get_addon_data();
		
		if( !empty( $Data['latest'] ) ) {

			$latest_ver = $Data['latest'];
			
		} else {
			
			$this->update_addon_data();

		}
			
		return $latest_ver;
		
	}

	private function update_addon_data( $latest_ver = false ) {
		
		global $Plvc_Multiple;

		if( $latest_ver == false )
			$latest_ver = $Plvc_Multiple->ver;

		update_option( $this->AddonRecord , array( 'latest' => $latest_ver ) );

	}

}

endif;
